abacusai.drift_distributions — AbacusAI documentation

# abacusai.drift_distributions

## Classes

`DriftDistributions` | For either actuals or predicted values, how it has changed in the training data versus some specified window

## Module Contents

class abacusai.drift_distributions.DriftDistributions(client, labelDrift={}, predictionDrift={}, bpPredictionDrift={})

  Bases: `abacusai.return_class.AbstractApiClass`

  For either actuals or predicted values, how it has changed in the training data versus some specified window

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - labelDrift (DriftDistribution) – A DriftDistribution describing column names and the range of values for label drift.

    - predictionDrift (DriftDistribution) – A DriftDistribution describing column names and the range of values for prediction drift.

    - bpPredictionDrift (DriftDistribution) – A DriftDistribution describing column names and the range of values for prediction drift, when the predictions come from BP.

  label_drift
  prediction_drift
  bp_prediction_drift
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict